@@ -44,6 +44,8 @@ if(require("RUnit", quietly = TRUE))
                           fileName = paste(pathReport, ".txt", sep = ""))
 
         ## Print HTML Version to a File:
+        ## printHTMLProtocol has problems on Mac OS X
+        if (Sys.info()["sysname"] != "Darwin")
         printHTMLProtocol(tests,
                           fileName = paste(pathReport, ".html", sep = ""))
 
